@@ -70,18 +70,28 @@ readline_ <- function(...) {
 #' @param x Input passed to cat function.
 #' @return Prints x to clipboard.
 #' @examples
+#' \dontrun{
 #' ## alphabet as string
 #' pbcopy(paste(letters, collapse = ""))
 #' ## paste e.g., C-v
+#' }
 #' @export
 pbcopy <- function(x) {
   if (.Platform$OS.type == "unix" &&
-    !identical(Sys.which("pbcopy"), "")) {
+      grepl("^darwin", R.version$os) &&
+    !identical(sys_which("pbcopy"), "")) {
     con <- pipe("pbcopy", "w")
   } else if (.Platform$OS.type == "windows") {
     con <- file("clipboard", "w")
   } else {
     stop("Please install 'pbcopy'", call. = FALSE)
   }
+  cat(x, file = con, fill = TRUE)
   close(con)
 }
+
+
+sys_which <- function(x) {
+  tryCatch(Sys.which(x),
+    error = function(e) "")
+}
